import React, { FC, useEffect } from "react";
import getConfig from "next/config";

import { useStoreState } from "../store";
import { ColCenter } from "./Layout";
import ALink from "./ALink";
import Text from "./Text";

const { publicRuntimeConfig } = getConfig();

const Footer: FC = () => {
  const { isAuthenticated } = useStoreState(s => s.auth);

  return (
    <ColCenter
      as="footer"
      width={1}
      backgroundColor="white"
      p={isAuthenticated ? 2 : 24}
    >
      {!isAuthenticated}
      <Text fontSize={[12, 13]} py={2}>
        Made with love by{" "}
        <ALink href="//thedevs.network/" title="The Devs">
          The Devs
        </ALink>
        {", "}  
        Forked with love by{" "}
        <ALink href="//thisisjoes.site/" title="Joe">
          Joe   
        </ALink>
        .{" | "}
        <ALink
          href="https://git.thisisjoes.site/joe/klip"
          title="Source"
          target="_blank"
        >
          Source Code
        </ALink>
        {" | "}
        <ALink href="/terms" title="Terms of Service">
          Terms of Service
        </ALink>
        {" | "}
        <ALink href="/report" title="Report abuse">
          Report Abuse
        </ALink>
        {publicRuntimeConfig.CONTACT_EMAIL && (
          <>
            {" | "}
            <ALink
              href={`mailto:${publicRuntimeConfig.CONTACT_EMAIL}`}
              title="Contact us"
            >
              Contact us
            </ALink>
          </>
        )}
        .
      </Text>
    </ColCenter>
  );
};

export default Footer;
